@@ -18,7 +18,11 @@ main()
 
 	# Run bootstrap test
 	sparrowdo --docker="$target" --no_sudo --bootstrap --module_run=Sparrow::Update --format=production && \
-	sparrowdo --docker="$target" --no_sudo --task_run=bash@command=uname
+	sparrowdo --docker="$target" --no_sudo --task_run=bash@command=uname && \
+  sparrowdo --docker="$target" --no_sudo --task_run=user@name=foo \
+  --task_run=bash@command='id && cd ~/ && pwd && uptime && ls -l && ps a|grep bash|grep -v grep',user=foo \
+  --task_run=df-check@therhold=54 \
+  --format=production
 
 }
 
